import type { JsonObject } from '../../../../types';
import type { SingleOrArray } from '../../../../utils';
import type { IssuerOptions } from '../../../vc/models/credential/Issuer';
import type { CredentialFormat } from '../CredentialFormat';
import type { JsonLdOptionsRFC0593 } from './JsonLdOptionsRFC0593';
export interface JsonCredential {
    '@context': Array<string> | JsonObject;
    id?: string;
    type: Array<string>;
    issuer: string | IssuerOptions;
    issuanceDate: string;
    expirationDate?: string;
    credentialSubject: SingleOrArray<JsonObject>;
    [key: string]: unknown;
}
export interface JsonLdSignCredentialFormat {
    credential: JsonCredential;
    options: JsonLdOptionsRFC0593;
}
export interface SignCredentialOptionsRFC0593 {
    credential: JsonCredential;
    options: JsonLdOptionsRFC0593;
}
export interface JsonVerifiableCredential extends JsonLdSignCredentialFormat {
    proof: {
        type: string;
        proofPurpose: string;
        verificationMethod: string;
        created: string;
        domain?: string;
        challenge?: string;
        jws?: string;
        proofValue?: string;
        nonce?: string;
        [key: string]: unknown;
    };
}
declare type EmptyObject = Record<string, never>;
export interface JsonLdCreateRequestFormat {
    verificationMethod?: string;
}
export interface JsonLdCredentialFormat extends CredentialFormat {
    formatKey: 'jsonld';
    credentialRecordType: 'w3c';
    credentialFormats: {
        createProposal: JsonLdSignCredentialFormat;
        acceptProposal: EmptyObject;
        createOffer: JsonLdSignCredentialFormat;
        acceptOffer: EmptyObject;
        createRequest: JsonLdSignCredentialFormat;
        acceptRequest: JsonLdCreateRequestFormat;
    };
    formatData: {
        proposal: JsonLdSignCredentialFormat;
        offer: JsonLdSignCredentialFormat;
        request: JsonLdSignCredentialFormat;
        credential: JsonVerifiableCredential;
    };
}
export {};
